#!/bin/sh

#set -x

PATCHNO=3

function usage
{

   /bin/echo "Usage: $0 [pathname]"
   /bin/echo "   [pathname] is an optional parameter specifying the CD mount point"
   /bin/echo "   or the path to the PDRTE-PD-3.8.0-0.i386.rpm file."
   /bin/echo ""
   exit 1
}


CDPATH=$1
BASEPATH=`dirname $0`
PROGNAME=`basename $0`
GOLDPATH=""
RHMASK_INSTALLED=0
INSTALL_PDRTE=1
UPGRADE_PDRTE=0
UPGRADE_PDAUTHADK=0
PDRTE_GOLD_INSTALLED=0
BUILD_PDRTE_RPM=0
BUILD_PDAUTHADK_RPM=0

/bin/echo ""
/bin/echo "Policy Director Runtime Base Patch Installation Script"
/bin/echo ""

# find path to the gold distribution
/bin/echo -n "Checking for GOLD filesets..."
if [ -f "$BASEPATH/PDRTE-PD-3.8.0-0.i386.rpm" ]; then
   GOLDPATH=$BASEPATH
elif [ -f "$CDPATH/PDRTE-PD-3.8.0-0.i386.rpm" ]; then
   GOLDPATH=$CDPATH
elif [ -f "$CDPATH/linux/PDRTE-PD-3.8.0-0.i386.rpm" ]; then
   GOLDPATH=$CDPATH/linux
elif [ -f "/mnt/cdrom/linux/PDRTE-PD-3.8.0-0.i386.rpm" ]; then
   GOLDPATH=/mnt/cdrom/linux
fi
if [ -z "$GOLDPATH" ]; then
   /bin/echo "not found."
else
   /bin/echo "found."
fi

# is rhmask tool installed on the system?
/bin/echo -n "Checking for rhmask tool..."
/bin/rpm -q -i rhmask 2>/dev/null 1>/dev/null
if [ $? -eq 0 ]; then
   RHMASK_INSTALLED=1
   /bin/echo "found."
else
   /bin/echo "not found."
fi

# is PDRTE 3.8.0 installed?
/bin/echo -n "Checking for installation of PDRTE..."
PDRTE_VER=`/bin/rpm -q --qf '%{VERSION}' PDRTE-PD 2>/dev/null`
if [ $? -eq 0 ]; then
   if [ "$PDRTE_VER" = "3.8.0" ]; then
      PDRTE_REL=`/bin/rpm -q --qf '%{RELEASE}' PDRTE-PD 2>/dev/null`
      /bin/echo "3.8.0-$PDRTE_REL found."
      if [ $PDRTE_REL -eq 0 ]; then
         PDRTE_GOLD_INSTALLED=1
         UPGRADE_PDRTE=1
      elif [ $PDRTE_REL -lt $PATCHNO ]; then
         UPGRADE_PDRTE=1
      else
         INSTALL_PDRTE=0
      fi 
   else
      INSTALL_PDRTE=0
      /bin/echo "post-3.8.0 release found."
   fi
else 
   /bin/echo "not found."
fi

if [ $INSTALL_PDRTE -eq 0 ]; then
   # Nothing to do - a later version is installed
   /bin/echo "No patch installation required."
   exit 0
fi


/bin/echo -n "Checking for installation of PDAuthADK..."
PDAUTHADK_VER=`/bin/rpm -q --qf '%{VERSION}' PDAuthADK-PD 2>/dev/null`
if [ $? -eq 0 ]; then
   if [ "$PDAUTHADK_VER" = "3.8.0" ]; then
      PDAUTHADK_REL=`/bin/rpm -q --qf '%{RELEASE}' PDAuthADK-PD 2>/dev/null`
      if [ $PDAUTHADK_REL -lt $PATCHNO ]; then
         UPGRADE_PDAUTHADK=1
      fi
      /bin/echo "3.8.0-$PDAUTHADK_REL found."
   else
      /bin/echo "post-3.8.0 release found."
   fi
else
   /bin/echo "not found."
fi

# see if we need to build the RPMs from the rhmask file
RTEPATCH="PDRTE-PD-3.8.0-"$PATCHNO".i386.rpm"
/bin/echo -n "Checking for PDRTE update RPM $RTEPATCH..."
if [ ! -f "$BASEPATH/$RTEPATCH" ]; then
   if [ ! -f "$BASEPATH/$RTEPATCH.rhmask" ]; then
      /bin/echo ""
      /bin/echo "ERROR:  Unable to find runtime RPM or RPM.rhmask file."
      /bin/echo "The $PROGNAME tool must be run from the same directory as"
      /bin/echo "the patch RPM or RPM.rhmask files."
      /bin/echo ""
      usage
   else
      BUILD_PDRTE_RPM=1
   fi
fi
if [ $BUILD_PDRTE_RPM -eq 1 ]; then
   /bin/echo "not found."
else
   /bin/echo "found."
fi

# build the PDAUTHADK RPM?
ADKPATCH="PDAuthADK-PD-3.8.0-"$PATCHNO".i386.rpm"
/bin/echo -n "Checking for PDAuthADK update RPM $ADKPATCH..."
if [ ! -f "$BASEPATH/$ADKPATCH" ]; then
   if [  -f "$BASEPATH/$ADKPATCH.rhmask" ]; then
      BUILD_PDAUTHADK_RPM=1
   fi
fi
if [ $BUILD_PDAUTHADK_RPM -eq 1 ]; then
   /bin/echo "not found."
else
   /bin/echo "found."
fi

if [ $BUILD_PDAUTHADK_RPM -eq 1 -o $BUILD_PDRTE_RPM -eq 1 ]; then
   if [ $RHMASK_INSTALLED -eq 0 ]; then
      /bin/echo "ERROR: The rhmask tool is required to create the updated RPMs."
      /bin/echo "Please install the rhmask tool from the RedHat distribution."
      exit 1
   fi
fi

echo ""
# create the PDRTE RPM
if [ $BUILD_PDRTE_RPM -eq 1 ]; then
   if [ ! -f "$GOLDPATH/PDRTE-PD-3.8.0-0.i386.rpm" ]; then
      /bin/echo "ERROR: Unable to find the PDRTE-PD-3.8.0-0.i386.rpm package."
      /bin/echo "Please mount the Tivoli Secureway Policy Director Base for"
      /bin/echo "AIX and Linux CD-ROM at /mnt/cdrom, or specify the path"
      /bin/echo "to the files when running this install script."
      /bin/echo ""
      usage
   fi
   /bin/echo "Building the PDRTE RPM..."
   /usr/bin/rhmask $GOLDPATH/PDRTE-PD-3.8.0-0.i386.rpm "$RTEPATCH.rhmask"
   if [ $? -ne 0 ]; then
      /bin/echo ""
      /bin/echo "ERROR:  A failure occurred when running the rhmask utility."
      /bin/echo "Please make sure there is plenty of free space in the filesystem"
      /bin/echo "containing the \"$BASEPATH\" directory and that the current "
      /bin/echo "userid (`/usr/bin/whoami`) has write permission."
      /bin/echo ""
      exit 1
   fi
   /bin/echo "RPM build done."
   /bin/echo ""
fi

# create the PDAUTHADK RPM - skip if gold package not found
if [ $BUILD_PDAUTHADK_RPM -eq 1 ]; then
   if [ ! -f "$GOLDPATH/PDAuthADK-PD-3.8.0-0.i386.rpm" ]; then
      /bin/echo "WARNING: Unable to find the PDAuthADK-PD-3.8.0-0.i386.rpm package."
      /bin/echo "Please mount the Tivoli Secureway Policy Director Base for"
      /bin/echo "AIX and Linux CD-ROM at /mnt/cdrom, or specify the path"
      /bin/echo "to the files when running this install script."
      /bin/echo ""
   else
      /bin/echo "Building the PDAuthADK RPM..."
      /usr/bin/rhmask $GOLDPATH/PDAuthADK-PD-3.8.0-0.i386.rpm "$ADKPATCH.rhmask"
      if [ $? -ne 0 ]; then
         /bin/echo ""
         /bin/echo "ERROR:  A failure occurred when running the rhmask utility."
         /bin/echo "Please make sure there is plenty of free space in the filesystem"
         /bin/echo "containing the \"$BASEPATH\" directory and that the current "
         /bin/echo "userid (`/usr/bin/whoami`) has write permission."
         /bin/echo ""
         exit 1
      fi
      /bin/echo "RPM build done."
      /bin/echo ""
   fi
fi

# install the patches
if [ $UPGRADE_PDRTE -eq 1 ]; then
   /bin/echo "Upgrading PDRTE..."
   if [ $PDRTE_GOLD_INSTALLED -eq 1 ]; then
      rpm -U "$BASEPATH/$RTEPATCH" --noscripts
      if [ $? -ne 0 ]; then
         /bin/echo "ERROR:  A failure occurred upgrading the $RTEPATCH package."
         /bin/echo "Please confirm that the current userid had the authority to"
         /bin/echo "install packages."
         exit 1
      fi
   else
      rpm -U "$BASEPATH/$RTEPATCH"
      if [ $? -ne 0 ]; then
         /bin/echo "ERROR:  A failure occurred upgrading the $RTEPATCH package."
         /bin/echo "Please confirm that the current userid had the authority to"
         /bin/echo "install packages."
         exit 1
      fi
   fi
   /bin/echo "Upgrade done."
   /bin/echo ""
else
   /bin/echo "Installing PDRTE..."
   rpm -i "$BASEPATH/$RTEPATCH"
   if [ $? -ne 0 ]; then
      /bin/echo "ERROR:  A failure occurred installing the $RTEPATCH package."
      /bin/echo "Please confirm that the current userid had the authority to"
      /bin/echo "install packages."
      exit 1
   fi
   /bin/echo "Installation done."
   /bin/echo ""
fi


if [ $UPGRADE_PDAUTHADK -eq 1 ]; then
   /bin/echo "Upgrading PDAuthADK..."
   rpm -U "$BASEPATH/$ADKPATCH"
   if [ $? -ne 0 ]; then
      /bin/echo "ERROR:  A failure occurred upgrading the $ADKPATCH package."
      /bin/echo "Please confirm that the current userid had the authority to"
      /bin/echo "install packages."
      exit 1
   fi
   /bin/echo "Upgrade done."
   /bin/echo ""
else
   /bin/echo "This patch install script does not install the PDAuthADK package."
   /bin/echo "To install the latest PDAuthADK on your system, run the following command:"
   /bin/echo ""
   /bin/echo "rpm -i \"$BASEPATH/$ADKPATCH\""
   /bin/echo ""
fi

/bin/echo "Patch installation process complete."

